@@ -304,7 +304,10 @@ impl<'src> Expr<'src> {
                     || func == "startsWith"
                     || func == "endsWith"
                     || func == "toJSON"
-                    || func == "fromJSON"
+                    // TODO(ww): `fromJSON` *is* frequently reducible, but
+                    // doing so soundly with subexpressions is annoying.
+                    // We overapproximate for now and consider it non-reducible.
+                    // || func == "fromJSON"
                     || func == "join"
                 {
                     args.iter().all(|e| e.constant_reducible())
@@ -318,6 +321,7 @@ impl<'src> Expr<'src> {
     }
 
     /// Parses the given string into an expression.
+    #[allow(clippy::unwrap_used)]
     pub fn parse(expr: &'src str) -> Result<SpannedExpr<'src>> {
         // Top level `expression` is a single `or_expr`.
         let or_expr = ExprParser::parse(Rule::expression, expr)?
